@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: socks
-version: 0.5.4
-id: socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
-key: socks_BZJ6e1EePGtK56UKTxGOcA
+version: 0.5.5
+id: socks-0.5.5-0c45c80c2330de843f6569e694fbea7d
+key: socks_0YMyCkcHxoaGiGc8lAEaV3
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -18,12 +18,12 @@ exposed: True
 exposed-modules:
     Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
 hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
-                Network.Socks5.Command
+                Network.Socks5.Command Network.Socks5.Parse
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/socks-0.5.4
-hs-libraries: HSsocks-0.5.4-BZJ6e1EePGtK56UKTxGOcA
+import-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/socks-0.5.5
+hs-libraries: HSsocks-0.5.5-0YMyCkcHxoaGiGc8lAEaV3
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
